@@ -494,28 +494,6 @@ class GetBooleanvReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 class GetBooleanvCookie(xcffib.Cookie):
     reply_type = GetBooleanvReply
-class GetClipPlaneReply(xcffib.Reply):
-    def __init__(self, unpacker):
-        if isinstance(unpacker, xcffib.Protobj):
-            unpacker = xcffib.MemoryUnpacker(unpacker.pack())
-        xcffib.Reply.__init__(self, unpacker)
-        base = unpacker.offset
-        unpacker.unpack("xx2x4x24x")
-        self.data = xcffib.List(unpacker, "d", self.length // 2)
-        self.bufsize = unpacker.offset - base
-class GetClipPlaneCookie(xcffib.Cookie):
-    reply_type = GetClipPlaneReply
-class GetDoublevReply(xcffib.Reply):
-    def __init__(self, unpacker):
-        if isinstance(unpacker, xcffib.Protobj):
-            unpacker = xcffib.MemoryUnpacker(unpacker.pack())
-        xcffib.Reply.__init__(self, unpacker)
-        base = unpacker.offset
-        self.n, self.datum = unpacker.unpack("xx2x4x4xId8x")
-        self.data = xcffib.List(unpacker, "d", self.n)
-        self.bufsize = unpacker.offset - base
-class GetDoublevCookie(xcffib.Cookie):
-    reply_type = GetDoublevReply
 class GetErrorReply(xcffib.Reply):
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
@@ -570,17 +548,6 @@ class GetLightivReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 class GetLightivCookie(xcffib.Cookie):
     reply_type = GetLightivReply
-class GetMapdvReply(xcffib.Reply):
-    def __init__(self, unpacker):
-        if isinstance(unpacker, xcffib.Protobj):
-            unpacker = xcffib.MemoryUnpacker(unpacker.pack())
-        xcffib.Reply.__init__(self, unpacker)
-        base = unpacker.offset
-        self.n, self.datum = unpacker.unpack("xx2x4x4xId8x")
-        self.data = xcffib.List(unpacker, "d", self.n)
-        self.bufsize = unpacker.offset - base
-class GetMapdvCookie(xcffib.Cookie):
-    reply_type = GetMapdvReply
 class GetMapfvReply(xcffib.Reply):
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
@@ -702,17 +669,6 @@ class GetTexEnvivReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 class GetTexEnvivCookie(xcffib.Cookie):
     reply_type = GetTexEnvivReply
-class GetTexGendvReply(xcffib.Reply):
-    def __init__(self, unpacker):
-        if isinstance(unpacker, xcffib.Protobj):
-            unpacker = xcffib.MemoryUnpacker(unpacker.pack())
-        xcffib.Reply.__init__(self, unpacker)
-        base = unpacker.offset
-        self.n, self.datum = unpacker.unpack("xx2x4x4xId8x")
-        self.data = xcffib.List(unpacker, "d", self.n)
-        self.bufsize = unpacker.offset - base
-class GetTexGendvCookie(xcffib.Cookie):
-    reply_type = GetTexGendvReply
 class GetTexGenfvReply(xcffib.Reply):
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
@@ -790,6 +746,16 @@ class GetTexLevelParameterivReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 class GetTexLevelParameterivCookie(xcffib.Cookie):
     reply_type = GetTexLevelParameterivReply
+class IsEnabledReply(xcffib.Reply):
+    def __init__(self, unpacker):
+        if isinstance(unpacker, xcffib.Protobj):
+            unpacker = xcffib.MemoryUnpacker(unpacker.pack())
+        xcffib.Reply.__init__(self, unpacker)
+        base = unpacker.offset
+        self.ret_val, = unpacker.unpack("xx2x4xI")
+        self.bufsize = unpacker.offset - base
+class IsEnabledCookie(xcffib.Cookie):
+    reply_type = IsEnabledReply
 class IsListReply(xcffib.Reply):
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
@@ -1044,7 +1010,6 @@ class glxExtension(xcffib.Extension):
     def Render(self, context_tag, data_len, data, is_checked=False):
         buf = six.BytesIO()
         buf.write(struct.pack("=xx2xI", context_tag))
-        buf.write("")
         buf.write(xcffib.pack_list(data, "B"))
         return self.send_request(1, buf, is_checked=is_checked)
     def RenderLarge(self, context_tag, request_num, request_total, data_len, data, is_checked=False):
@@ -1107,13 +1072,11 @@ class glxExtension(xcffib.Extension):
     def VendorPrivate(self, vendor_code, context_tag, data_len, data, is_checked=False):
         buf = six.BytesIO()
         buf.write(struct.pack("=xx2xII", vendor_code, context_tag))
-        buf.write("")
         buf.write(xcffib.pack_list(data, "B"))
         return self.send_request(16, buf, is_checked=is_checked)
     def VendorPrivateWithReply(self, vendor_code, context_tag, data_len, data, is_checked=True):
         buf = six.BytesIO()
         buf.write(struct.pack("=xx2xII", vendor_code, context_tag))
-        buf.write("")
         buf.write(xcffib.pack_list(data, "B"))
         return self.send_request(17, buf, VendorPrivateWithReplyCookie, is_checked=is_checked)
     def QueryExtensionsString(self, screen, is_checked=True):
@@ -1248,14 +1211,14 @@ class glxExtension(xcffib.Extension):
         buf = six.BytesIO()
         buf.write(struct.pack("=xx2xIi", context_tag, pname))
         return self.send_request(112, buf, GetBooleanvCookie, is_checked=is_checked)
-    def GetClipPlane(self, context_tag, plane, is_checked=True):
+    def GetClipPlane(self, context_tag, plane, is_checked=False):
         buf = six.BytesIO()
         buf.write(struct.pack("=xx2xIi", context_tag, plane))
-        return self.send_request(113, buf, GetClipPlaneCookie, is_checked=is_checked)
-    def GetDoublev(self, context_tag, pname, is_checked=True):
+        return self.send_request(113, buf, is_checked=is_checked)
+    def GetDoublev(self, context_tag, pname, is_checked=False):
         buf = six.BytesIO()
         buf.write(struct.pack("=xx2xII", context_tag, pname))
-        return self.send_request(114, buf, GetDoublevCookie, is_checked=is_checked)
+        return self.send_request(114, buf, is_checked=is_checked)
     def GetError(self, context_tag, is_checked=True):
         buf = six.BytesIO()
         buf.write(struct.pack("=xx2xI", context_tag))
@@ -1276,10 +1239,10 @@ class glxExtension(xcffib.Extension):
         buf = six.BytesIO()
         buf.write(struct.pack("=xx2xIII", context_tag, light, pname))
         return self.send_request(119, buf, GetLightivCookie, is_checked=is_checked)
-    def GetMapdv(self, context_tag, target, query, is_checked=True):
+    def GetMapdv(self, context_tag, target, query, is_checked=False):
         buf = six.BytesIO()
         buf.write(struct.pack("=xx2xIII", context_tag, target, query))
-        return self.send_request(120, buf, GetMapdvCookie, is_checked=is_checked)
+        return self.send_request(120, buf, is_checked=is_checked)
     def GetMapfv(self, context_tag, target, query, is_checked=True):
         buf = six.BytesIO()
         buf.write(struct.pack("=xx2xIII", context_tag, target, query))
@@ -1324,10 +1287,10 @@ class glxExtension(xcffib.Extension):
         buf = six.BytesIO()
         buf.write(struct.pack("=xx2xIII", context_tag, target, pname))
         return self.send_request(131, buf, GetTexEnvivCookie, is_checked=is_checked)
-    def GetTexGendv(self, context_tag, coord, pname, is_checked=True):
+    def GetTexGendv(self, context_tag, coord, pname, is_checked=False):
         buf = six.BytesIO()
         buf.write(struct.pack("=xx2xIII", context_tag, coord, pname))
-        return self.send_request(132, buf, GetTexGendvCookie, is_checked=is_checked)
+        return self.send_request(132, buf, is_checked=is_checked)
     def GetTexGenfv(self, context_tag, coord, pname, is_checked=True):
         buf = six.BytesIO()
         buf.write(struct.pack("=xx2xIII", context_tag, coord, pname))
@@ -1356,6 +1319,10 @@ class glxExtension(xcffib.Extension):
         buf = six.BytesIO()
         buf.write(struct.pack("=xx2xIIiI", context_tag, target, level, pname))
         return self.send_request(139, buf, GetTexLevelParameterivCookie, is_checked=is_checked)
+    def IsEnabled(self, context_tag, capability, is_checked=True):
+        buf = six.BytesIO()
+        buf.write(struct.pack("=xx2xII", context_tag, capability))
+        return self.send_request(140, buf, IsEnabledCookie, is_checked=is_checked)
     def IsList(self, context_tag, list, is_checked=True):
         buf = six.BytesIO()
         buf.write(struct.pack("=xx2xII", context_tag, list))
